==> canon-runtime-java-0.0.32-sources.jar: org/symphonyoss/s2/canon/runtime/ByteStringTypeDefBuilder.java <==
/*
 *
 *
 * Copyright 2018 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import javax.annotation.Nonnull;

import org.apache.commons.codec.binary.Base64;
import org.symphonyoss.s2.common.dom.json.JsonString;
import org.symphonyoss.s2.common.dom.json.JsonValue;

import com.google.protobuf.ByteString;

public abstract class ByteStringTypeDefBuilder<M> extends TypeDefBuilder<M,ByteString>
{
  @Override
  public M build(@Nonnull JsonValue<?, ?> jsonValue)
  {
    if(jsonValue instanceof JsonString)
    {
      return build(
          ByteString.copyFrom(
              Base64.decodeBase64(
                  ((JsonString)jsonValue).asString()
              )
          )
      );
    }
    
    throw new IllegalArgumentException("Expected a string but found a " + jsonValue.getClass().getName());
  }

}

==> canon-runtime-java-0.2.2-sources.jar: org/symphonyoss/s2/canon/runtime/ByteStringTypeDefBuilder.java <==
/*
 *
 *
 * Copyright 2018 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import javax.annotation.Nonnull;

import org.apache.commons.codec.binary.Base64;
import org.symphonyoss.s2.common.dom.json.JsonString;
import org.symphonyoss.s2.common.type.provider.IValueProvider;

import com.google.protobuf.ByteString;

public abstract class ByteStringTypeDefBuilder<M> extends TypeDefBuilder<M,ByteString>
{
  @Override
  public M build(@Nonnull IValueProvider jsonValue)
  {
    if(jsonValue instanceof JsonString)
    {
      return build(
          ByteString.copyFrom(
              Base64.decodeBase64(
                  ((JsonString)jsonValue).asString()
              )
          )
      );
    }
    
    throw new IllegalArgumentException("Expected a string but found a " + jsonValue.getClass().getName());
  }

}
